import React, { useState, useEffect } from 'react';

import { Form, Select, Modal, Button,Table, Divider, Tag } from 'antd';
import { apis, fetch } from '../../utils/request';

const getHelpList = fetch(apis.helpActivity.effectiveList)

export default props => {
  const {
    value,
    onChange,
    ...rest
  } = props;

  const [list, setList] = useState([]);
  const [visible, setVisible] = useState(false);
  const [help, setHelp] = useState({ helpId: undefined, helpName: '请选择助力' })
  const getHelpTitle = val => {
    return (list.filter(x => x.helpActivityId == val)[0] || {}).title || '请选择助力'
  }

  const updateHelp = val => setHelp({ helpId: val, helpName: getHelpTitle(val) })

  const buildingId = props.buildingId()

  useEffect(() => {
    getHelpList({
      params: {
        buildingId,
        pageNum: 1,
        pageSize: 999,
        status: 1
      },
    }).then(data => {
      setList(data.records || [])

      updateHelp(value ? undefined : value);
    })
  }, [buildingId]);

  if (value !== help.helpId) {
    updateHelp(value);
  }

  const handleChange = val => {
    onChange(val)
  }

  const setData=val=>{
    updateHelp(val)
    onChange(val)
    setVisible(false)
  }

  const columns = [
    {
      title: '标题',
      dataIndex: 'title',
      key: 'helpActivityId',
      align:'center',
      ellipsis:true,
      render: text => <a>{text}</a>,
    },
    {
      title: '操作',
      align:'center',
      width:'20%',
      render: (text, record) => (
        <span>
          <a onClick={() => setData(record.helpActivityId)} style={{color:'blue'}}>选择</a>
        </span>
      ),
    },
  ];

  return (
    <div>
      <div onClick={() => setVisible(true)}>{help.helpName}</div>
        <Modal
          title="请选择H5"
          visible={visible}
           onCancel={() => setVisible(false)}
           footer={[]}
        >
         <Table rowKey={list => list.helpActivityId} columns={columns} dataSource={list} />
        </Modal>
    </div>
  );
}
