import React, { useState, useEffect } from 'react';
import { Form, Select, Modal, Button,Table, Divider, Tag } from 'antd';
import { apis, fetch } from '../../utils/request';

const getNewsList = fetch(apis.news.getList)

export default props => {
  const {
    value,
    onChange,
    ...rest
  } = props;

  const [list, setList] = useState([]);
  const [visible, setVisible] = useState(false);
  const [news, setNews] = useState({ newsId: undefined, newsName: '请选择资讯' })
  const getNewsTitle = val => ((list.filter(x => x.newsId == val)[0]) || {}).newsName || '请选择资讯'
  const updateNews = val => setNews({ newsId: val, newsName: getNewsTitle(val) })

  const buildingId = props.buildingId()

  useEffect(() => {
    getNewsList({
      params: {
        buildingId,
        pageNum: 1,
        pageSize: 999,
        newsStatus: 0,
      },
    }).then(data => {
      setList(data.records || [])

      updateNews(buildingId ? undefined : value);
    })
  }, [buildingId]);

  if (value !== news.newsId) {
    updateNews(value);
  }

  const handleChange = val => {
    onChange(val)
  }

  const setData=val=>{
    updateNews(val)
    onChange(val)
    setVisible(false)
  }

  const columns = [
    {
      title: '标题',
      dataIndex: 'newsName',
      key: 'newsId',
      align:'center',
      ellipsis:true,
      render: text => <a>{text}</a>,
    },
    {
      title: '操作',
      align:'center',
      width:'20%',
      render: (text, record) => (
        <span>
          <a onClick={() => setData(record.newsId)} style={{color:'blue'}}>选择</a>
        </span>
      ),
    },
  ];

  return (
    <div>
      <div onClick={() => setVisible(true)}>{news.newsName}</div>
        <Modal
          title="请选择H5"
          visible={visible}
           onCancel={() => setVisible(false)}
           footer={[]}
        >
         <Table rowKey={list => list.newsId} columns={columns} dataSource={list} />
        </Modal>
    </div>
  );
}
